@@ -13,7 +13,6 @@
 #include <KJobUiDelegate>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KNS3/QtQuickDialogWrapper>
 #include <KTar>
 
 #include <QDir>
@@ -47,11 +46,9 @@ AppearanceSettings::AppearanceSettings(QWidget *parent)
 
     installButton->setIcon(QIcon::fromTheme(QStringLiteral("folder")));
     removeButton->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
-    ghnsButton->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
+    ghnsButton->setConfigFile(QStringLiteral("yakuake.knsrc"));
 
-    m_knsConfigFileName = QLatin1String("yakuake.knsrc");
-
-    connect(ghnsButton, &QPushButton::clicked, this, &AppearanceSettings::getNewSkins);
+    connect(ghnsButton, &KNSWidgets::Button::dialogFinished, this, &AppearanceSettings::knsDialogFinished);
 
     m_selectedSkinId = Settings::skin();
 
@@ -208,7 +205,7 @@ void AppearanceSettings::installSkin()
     m_installSkinFile.open();
 
     KIO::CopyJob *job = KIO::copy(skinUrl, QUrl::fromLocalFile(m_installSkinFile.fileName()), KIO::JobFlag::HideProgressInfo | KIO::JobFlag::Overwrite);
-    connect(job, &KIO::CopyJob::result, [=](KJob *job) {
+    connect(job, &KIO::CopyJob::result, [=, this](KJob *job) {
         if (job->error()) {
             job->uiDelegate()->showErrorMessage();
             job->kill();
@@ -228,7 +225,7 @@ void AppearanceSettings::installSkin(const QUrl &skinUrl)
     skinArchiveUrl.setScheme(QStringLiteral("tar"));
 
     KIO::ListJob *job = KIO::listRecursive(skinArchiveUrl, KIO::HideProgressInfo, false);
-    connect(job, &KIO::ListJob::entries, [=](KIO::Job * /* job */, const KIO::UDSEntryList &list) {
+    connect(job, &KIO::ListJob::entries, [=, this](KIO::Job * /* job */, const KIO::UDSEntryList &list) {
         if (list.isEmpty())
             return;
 
@@ -237,7 +234,7 @@ void AppearanceSettings::installSkin(const QUrl &skinUrl)
             m_installSkinFileList.append(i.next().stringValue(KIO::UDSEntry::UDS_NAME));
     });
 
-    connect(job, &KIO::ListJob::result, this, [=](KJob *job) {
+    connect(job, &KIO::ListJob::result, this, [=, this](KJob *job) {
         if (!job->error())
             checkForExistingSkin();
         else
@@ -283,7 +280,7 @@ void AppearanceSettings::checkForExistingSkin()
                                                             KGuiItem(xi18nc("@action:button", "Reinstall Skin")));
 
             if (remove == KMessageBox::Continue)
-                removeSkin(skinDir, [=]() {
+                removeSkin(skinDir, [this]() {
                     installSkinArchive();
                 });
             else
@@ -296,7 +293,7 @@ void AppearanceSettings::checkForExistingSkin()
 void AppearanceSettings::removeSkin(const QString &skinDir, std::function<void()> successCallback)
 {
     KIO::DeleteJob *job = KIO::del(QUrl::fromLocalFile(skinDir), KIO::HideProgressInfo);
-    connect(job, &KIO::DeleteJob::result, this, [=](KJob *deleteJob) {
+    connect(job, &KIO::DeleteJob::result, this, [=, this](KJob *deleteJob) {
         if (deleteJob->error()) {
             KMessageBox::error(parentWidget(), deleteJob->errorString(), xi18nc("@title:Window", "Could Not Delete Skin"));
         } else if (successCallback) {
@@ -380,7 +377,7 @@ void AppearanceSettings::removeSelectedSkin()
                                                     KStandardGuiItem::del());
 
     if (remove == KMessageBox::Continue)
-        removeSkin(skinDir, [=]() {
+        removeSkin(skinDir, [=, this]() {
             QString skinId = skinList->currentIndex().data(SkinId).toString();
             if (skinId == Settings::skin()) {
                 Settings::setSkin(QStringLiteral("default"));
@@ -420,87 +417,74 @@ QSet<QString> AppearanceSettings::extractKnsSkinIds(const QStringList &fileList)
     return skinIdList;
 }
 
-void AppearanceSettings::getNewSkins()
+void AppearanceSettings::knsDialogFinished(const QList<KNSCore::Entry> &changedEntries)
 {
-    QPointer<KNS3::QtQuickDialogWrapper> dialog = new KNS3::QtQuickDialogWrapper(m_knsConfigFileName, this);
-    dialog->open();
-    connect(dialog, &KNS3::QtQuickDialogWrapper::closed, this, [this, dialog] {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        const QList<KNSCore::EntryInternal> changedEntries = dialog->changedEntries();
+    quint32 invalidEntryCount = 0;
+    QString invalidSkinText;
+    for (const auto &entry : changedEntries) {
+#if QT_VERSION_MAJOR < 6
+        auto Installed = KNS3::Entry::Installed;
 #else
-            const QList<KNSCore::Entry> changedEntries = dialog->changedEntries();
+        auto Installed = KNSCore::Entry::Installed;
 #endif
-        quint32 invalidEntryCount = 0;
-        QString invalidSkinText;
-        for (const auto &_entry : changedEntries) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            if (_entry.status() != KNS3::Entry::Installed) {
-#else
-                if (_entry.status() != KNSCore::Entry::Installed) {
-#endif
-                continue;
-            }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            const KNSCore::EntryInternal &entry = _entry;
-#else
-                const KNSCore::Entry &entry = _entry;
-#endif
-            bool isValid = true;
-            const QSet<QString> &skinIdList = extractKnsSkinIds(entry.installedFiles());
+        if (entry.status() != Installed) {
+            continue;
+        }
+        bool isValid = true;
+        const QSet<QString> &skinIdList = extractKnsSkinIds(entry.installedFiles());
 
-            // Validate all skin IDs as each archive can contain multiple skins.
-            for (const QString &skinId : skinIdList) {
-                // Validate the current skin.
-                if (!validateSkin(skinId, true)) {
-                    isValid = false;
+        // Validate all skin IDs as each archive can contain multiple skins.
+        for (const QString &skinId : skinIdList) {
+            // Validate the current skin.
+            if (!validateSkin(skinId, true)) {
+                isValid = false;
+            }
+        }
+
+        // We'll add an error message for the whole KNS entry if
+        // the current skin is marked as invalid.
+        // We should not do this per skin as the user does not know that
+        // there are more skins inside one archive.
+        if (!isValid) {
+            invalidEntryCount++;
+
+            // The user needs to know the name of the skin which
+            // was removed.
+            invalidSkinText += QString(QStringLiteral("<li>%1</li>")).arg(entry.name());
+
+            // Then remove the skin.
+            const QStringList files = entry.installedFiles();
+            for (const QString &file : files) {
+                QFileInfo info(QString(file).remove(QStringLiteral("/*")));
+                if (!info.exists()) {
+                    continue;
                 }
-            }
-
-            // We'll add an error message for the whole KNS entry if
-            // the current skin is marked as invalid.
-            // We should not do this per skin as the user does not know that
-            // there are more skins inside one archive.
-            if (!isValid) {
-                invalidEntryCount++;
-
-                // The user needs to know the name of the skin which
-                // was removed.
-                invalidSkinText += QString(QStringLiteral("<li>%1</li>")).arg(entry.name());
-
-                // Then remove the skin.
-                const QStringList files = entry.installedFiles();
-                for (const QString &file : files) {
-                    QFileInfo info(QString(file).remove(QStringLiteral("/*")));
-                    if (!info.exists()) {
-                        continue;
-                    }
-                    if (info.isDir()) {
-                        QDir(info.absoluteFilePath()).removeRecursively();
-                    } else {
-                        QFile::remove(info.absoluteFilePath());
-                    }
+                if (info.isDir()) {
+                    QDir(info.absoluteFilePath()).removeRecursively();
+                } else {
+                    QFile::remove(info.absoluteFilePath());
                 }
             }
         }
+    }
 
-        // Are there any invalid entries?
-        if (invalidEntryCount > 0) {
-            failInstall(xi18ncp("@info",
-                                "The following skin is missing required files. Thus it was removed:<ul>%2</ul>",
-                                "The following skins are missing required files. Thus they were removed:<ul>%2</ul>",
-                                invalidEntryCount,
-                                invalidSkinText));
-        }
+    // Are there any invalid entries?
+    if (invalidEntryCount > 0) {
+        failInstall(xi18ncp("@info",
+                            "The following skin is missing required files. Thus it was removed:<ul>%2</ul>",
+                            "The following skins are missing required files. Thus they were removed:<ul>%2</ul>",
+                            invalidEntryCount,
+                            invalidSkinText));
+    }
 
-        if (!changedEntries.isEmpty()) {
-            // Reset the selection in case the currently selected
-            // skin was removed.
-            resetSelection();
+    if (!changedEntries.isEmpty()) {
+        // Reset the selection in case the currently selected
+        // skin was removed.
+        resetSelection();
 
-            // Re-populate the list of skins if the user changed something.
-            populateSkinList();
-        }
-
-        dialog->deleteLater();
-    });
+        // Re-populate the list of skins if the user changed something.
+        populateSkinList();
+    }
 }
+
+#include "moc_appearancesettings.cpp"
