@@ -839,7 +839,7 @@ void MainWindow::configureApp()
     settingsDialog->button(QDialogButtonBox::Help)->hide();
     settingsDialog->button(QDialogButtonBox::Cancel)->setFocus();
 
-    connect(settingsDialog, &QDialog::finished, [=]() {
+    connect(settingsDialog, &QDialog::finished, [=, this]() {
         m_toggleLock = true;
         KWindowSystem::activateWindow(windowHandle());
         KX11Extras::forceActiveWindow(winId());
@@ -881,7 +881,11 @@ void MainWindow::applySettings()
 
         // Prevent the default implementation of showing
         // and instead run toggleWindowState
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         m_notifierItem->setAssociatedWidget(nullptr);
+#else
+        m_notifierItem->setAssociatedWindow(nullptr);
+#endif
         connect(m_notifierItem, &KStatusNotifierItem::activateRequested, this, &MainWindow::toggleWindowState);
         updateTrayTooltip();
     }
@@ -1176,7 +1180,7 @@ void MainWindow::toggleWindowState()
         QDBusPendingCall call = QDBusConnection::sessionBus().asyncCall(message);
         QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
 
-        QObject::connect(watcher, &QDBusPendingCallWatcher::finished, this, [=]() {
+        QObject::connect(watcher, &QDBusPendingCallWatcher::finished, this, [=, this]() {
             QDBusPendingReply<QRect> reply = *watcher;
             m_availableScreenRect = reply.isValid() ? reply.value() : QRect();
             setWindowGeometry(Settings::width(), Settings::height(), Settings::position());
@@ -1661,3 +1665,5 @@ void MainWindow::updateTrayTooltip()
         m_notifierItem->setToolTip(QStringLiteral("yakuake"), QStringLiteral("Yakuake"), xi18nc("@info", "Press <shortcut>%1</shortcut> to open", shortcut));
     }
 }
+
+#include "moc_mainwindow.cpp"
