@@ -14,7 +14,7 @@ class Splitter : public QSplitter
     Q_OBJECT
 
 public:
-    explicit Splitter(Qt::Orientation orientation, QWidget *parent = 0);
+    explicit Splitter(Qt::Orientation orientation, QWidget *parent = nullptr);
     ~Splitter();
 
     void recursiveCleanup();
